#include <QtCore/QUrl>
#include <QGuiApplication>
#include <QScreen>
#include <QQmlApplicationEngine>
#include <QtWebView/QtWebView>
#include <QQmlContext>
#include <QDebug>

int main(int argc, char *argv[])
{
    QtWebView::initialize();
    QGuiApplication app(argc, argv);
	QGuiApplication::setApplicationDisplayName(QCoreApplication::translate("main", "QtWebView Test"));

	// Copy View.html from the resources to the app's data directory
	QString sourcePath = "assets:/View.html";
	QString destPath = QDir(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation)).absolutePath() + "/View.html";
	if (QFile::exists(sourcePath))
	{
		if (QFile::exists(destPath))
			qDebug() << "View.html already exists at" << sourcePath;
		else
		{
			bool success = QFile::copy(sourcePath, destPath);
			qDebug() << "Copying" << sourcePath << "to" << destPath << (success ? "succeeded." : "failed.");
		}
	}
	else
		qDebug() << "Error:" << sourcePath << "not found.";

	// Test: Access the destination file
	QFile file(destPath);
	if (file.open(QIODevice::ReadOnly | QIODevice::Text))
		qDebug() << destPath << "could be opened via QFile.";
	else
		qDebug() << "Error: Could not open" << destPath << "via QFile.";

	// Set the URL for the WebView
	QQmlApplicationEngine engine;
	QQmlContext* qmlContext = engine.rootContext();
	qmlContext->setContextProperty("ViewUrl", destPath);

    engine.load(QUrl(QStringLiteral("qrc:/main.qml")));
    if (engine.rootObjects().isEmpty())
        return -1;

    return app.exec();
}
